/*
 * fadeSlideShow
 * v.2.2.0
 *
 * Copyright (c) 2010 Pascal Bajorat (http://www.pascal-bajorat.com)
 * Dual licensed under the MIT (below)
 * and GPL (http://www.gnu.org/licenses/gpl.txt) licenses.
 *
 *
 * http://plugins.jquery.com/project/fadeslideshow
 * http://www.pascal-bajorat.com
 
 MIT License
 
 Copyright (c) 2013 Pascal Bajorat
 
 Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 
 The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
(function ($) {
    $.each(['show', 'hide'], function (i, ev) {
        var el = $.fn[ev];
        $.fn[ev] = function () {
            this.trigger(ev);
            return el.apply(this, arguments);
        };
    });
})(jQuery);
jQuery.fn.fadeSlideShow = function (options) {
    return this.each(function () {

        fadeSlideShowSettings = jQuery.extend({
            width: 640, // default width of the slideshow
            height: 480, // default height of the slideshow
            speed: 'slow', // default animation transition speed
            interval: 3000, // default interval between image change
            PlayPauseElement: 'fssPlayPause', // default css id for the play / pause element
            PlayText: 'Play', // default play text
            ReplayText: 'Replay', // default replay text
            PauseText: 'Pause', // default pause text
            NextElement: 'fssNext', // default id for next button
            NextElementText: 'Next >', // default text for next button
            PrevElement: 'fssPrev', // default id for prev button
            PrevElementText: '< Prev', // default text for prev button
            ListElement: 'fssList', // default id for image / content controll list
            ListLi: 'fssLi', // default class for li's in the image / content controll 
            ListLiActive: 'fssActive', // default class for active state in the controll list
            addListToId: false, // add the controll list to special id in your code - default false
            allowKeyboardCtrl: true, // allow keyboard controlls left / right / space
            autoplay: true, // autoplay the slideshow
            loop: true, //loop the slideshow
            onFinish: null, //callback when slideshow finish
            modal: null, //modal or not
            closable: null, //closable or not
        }, options);

        // set style for wrapper element
        jQuery(this).css({
            width: fadeSlideShowSettings.width,
            height: fadeSlideShowSettings.height,
            position: 'relative',
            overflow: 'hidden'
        });

        // set styles for child element
        jQuery('> *', this).css({
            position: 'absolute',
            width: fadeSlideShowSettings.width,
            height: fadeSlideShowSettings.height
        });

        // count number of slides
        var Slides = jQuery('> *', this).length;
        Slides = Slides - 1;
        var ActSlide = Slides;
        // Set jQuery Slide short var
        var jQslide = jQuery('> *', this);
        // save this
        var fssThis = this;
        var intval = false;

        var autoplay = function () {
            intval = setInterval(function () {
                if (ActSlide == 1) {
                    stopAutoplay(1);
                } else {
                    jQuery('#' + fadeSlideShowSettings.PlayPauseElement).removeClass('replay').addClass('play');
                }
                jQslide.eq(ActSlide).fadeOut(fadeSlideShowSettings.speed);
                // if list is on change the active class
                if (fadeSlideShowSettings.ListElement) {
                    var setActLi = (Slides - ActSlide) + 1;
                    if (setActLi > Slides) {
                        setActLi = 0;
                    }
                    jQuery('#' + fadeSlideShowSettings.ListElement + ' li').removeClass(fadeSlideShowSettings.ListLiActive);
                    jQuery('#' + fadeSlideShowSettings.ListElement + ' li').eq(setActLi).addClass(fadeSlideShowSettings.ListLiActive);
                }

                if (ActSlide <= 0) {
                    jQslide.fadeIn(fadeSlideShowSettings.speed);
                    ActSlide = Slides;
                } else {
                    ActSlide = ActSlide - 1;
                }

            }, fadeSlideShowSettings.interval);

//			if(fadeSlideShowSettings.PlayPauseElement){
//				jQuery('#'+fadeSlideShowSettings.PlayPauseElement).html(fadeSlideShowSettings.PauseText);
//			}
            jQuery('#' + fadeSlideShowSettings.PlayPauseElement).removeClass('play').addClass('pause');
        }

        var stopAutoplay = function (replay) {
            clearInterval(intval);
            intval = false;
//			if(fadeSlideShowSettings.PlayPauseElement){
//				jQuery('#'+fadeSlideShowSettings.PlayPauseElement).html(replay?fadeSlideShowSettings.ReplayText:fadeSlideShowSettings.PlayText);
//			}
            if (replay) {
                jQuery('#' + fadeSlideShowSettings.PlayPauseElement).removeClass('play').removeClass('pause').addClass('replay');
            } else {
                jQuery('#' + fadeSlideShowSettings.PlayPauseElement).removeClass('replay').removeClass('pause').addClass('play');
            }

            finish();//call the finish callback
        }

        var jumpTo = function (newIndex) {
            if (newIndex < 0) {
                newIndex = Slides;
            }
            else if (newIndex > Slides) {
                newIndex = 0;
            }
            if (newIndex >= ActSlide) {
                jQuery('> *:lt(' + (newIndex + 1) + ')', fssThis).fadeIn(fadeSlideShowSettings.speed);
            } else if (newIndex <= ActSlide) {
                jQuery('> *:gt(' + newIndex + ')', fssThis).fadeOut(fadeSlideShowSettings.speed);
            }

            // set the active slide
            ActSlide = newIndex;

            if (fadeSlideShowSettings.ListElement) {
                // set active
                jQuery('#' + fadeSlideShowSettings.ListElement + ' li').removeClass(fadeSlideShowSettings.ListLiActive);
                jQuery('#' + fadeSlideShowSettings.ListElement + ' li').eq((Slides - newIndex)).addClass(fadeSlideShowSettings.ListLiActive);
            }
        }

        var finish = function () {
            var s = this;

            if ($.isFunction(fadeSlideShowSettings.onFinish)) {
                // execute the onOpen callback
                fadeSlideShowSettings.onFinish.apply(s, [s.d]);
            }
        };

        // if list is on render it
        if (fadeSlideShowSettings.ListElement) {
            var i = 0;
            var li = '';
            while (i <= Slides) {
//				if(i==0){
//					li = li+'<li class="'+fadeSlideShowSettings.ListLi+i+' '+fadeSlideShowSettings.ListLiActive+'"><a href="#">'+(i+1)+'<\/a><\/li>';
//				}else{
//					li = li+'<li class="'+fadeSlideShowSettings.ListLi+i+'"><a href="#">'+(i+1)+'<\/a><\/li>';
//				}
                if (i == 0) {
                    li = li + '<li class="' + fadeSlideShowSettings.ListLi + ' ' + fadeSlideShowSettings.ListLiActive + '"><a href="#" class="fss"><\/a><\/li>';
                } else {
                    li = li + '<li class="' + fadeSlideShowSettings.ListLi + '"><a href="#" class="fss"><\/a><\/li>';
                }
                i++;
            }
            var List = '<ul id="' + fadeSlideShowSettings.ListElement + '">' + li + '<\/ul>';

            // add list to a special id or append after the slideshow
            if (fadeSlideShowSettings.addListToId) {
                jQuery('#' + fadeSlideShowSettings.addListToId).append(List);
            } else {
                jQuery(this).after(List);
            }

            jQuery('#' + fadeSlideShowSettings.ListElement + ' a').bind('click', function () {

                var index = jQuery('#' + fadeSlideShowSettings.ListElement + ' a').index(this);
                stopAutoplay();
                var ReverseIndex = Slides - index;

                jumpTo(ReverseIndex);

                return false;
            });
        }

        if (fadeSlideShowSettings.PlayPauseElement) {
            if (!jQuery('#' + fadeSlideShowSettings.PlayPauseElement).css('display')) {
                jQuery(this).after('<a href="#" id="' + fadeSlideShowSettings.PlayPauseElement + '" class="fss"><\/a>');
            }

//			if(fadeSlideShowSettings.autoplay){
//				jQuery('#'+fadeSlideShowSettings.PlayPauseElement).html(fadeSlideShowSettings.PauseText);
//			}else{
//				jQuery('#'+fadeSlideShowSettings.PlayPauseElement).html(fadeSlideShowSettings.PlayText);
//			}
            if (fadeSlideShowSettings.autoplay) {
                jQuery('#' + fadeSlideShowSettings.PlayPauseElement).removeClass('replay').removeClass('play').addClass('pause');
            } else {
                jQuery('#' + fadeSlideShowSettings.PlayPauseElement).removeClass('replay').removeClass('pause').addClass('play');
            }

            jQuery('#' + fadeSlideShowSettings.PlayPauseElement).bind('click', function () {
                if (intval) {
                    stopAutoplay();
                } else {
                    autoplay();
                }
                return false;
            });
        }

        if (fadeSlideShowSettings.NextElement) {
            if (!jQuery('#' + fadeSlideShowSettings.NextElement).css('display')) {
                jQuery(this).after('<a href="#" id="' + fadeSlideShowSettings.NextElement + '" class="fss">' + fadeSlideShowSettings.NextElementText + '<\/a>');
            }

            jQuery('#' + fadeSlideShowSettings.NextElement).bind('click', function () {
                nextSlide = ActSlide - 1;
                stopAutoplay();
                jumpTo(nextSlide);
                return false;
            });
        }

        if (fadeSlideShowSettings.PrevElement) {
            if (!jQuery('#' + fadeSlideShowSettings.PrevElement).css('display')) {
                jQuery(this).after('<a href="#" id="' + fadeSlideShowSettings.PrevElement + '" class="fss">' + fadeSlideShowSettings.PrevElementText + '<\/a>');
            }

            jQuery('#' + fadeSlideShowSettings.PrevElement).bind('click', function () {
                prevSlide = ActSlide + 1;
                stopAutoplay();
                jumpTo(prevSlide);
                return false;
            });
        }

        if (fadeSlideShowSettings.allowKeyboardCtrl) {
            jQuery(document).bind('keydown', function (e) {
                if (e.which == 39) {
                    var nextSlide = ActSlide - 1;
                    stopAutoplay();
                    jumpTo(nextSlide);
                } else if (e.which == 37) {
                    var prevSlide = ActSlide + 1;
                    stopAutoplay();
                    jumpTo(prevSlide);
                } else if (e.which == 32) {
                    if (intval) {
                        stopAutoplay();
                    }
                    else {
                        autoplay();
                    }
                    //return false;
                }
            });
        }

        if (fadeSlideShowSettings.closable) {
            // add the close button
            jQuery(this).after('<a class="slideshowCloseImg" title="Close"></a>');
            jQuery('a.slideshowCloseImg').bind('click', function (e) {
                e.preventDefault();
                jQuery("#slideshow-wrapper").hide();
                stopAutoplay();
                jQuery('#' + fadeSlideShowSettings.ListElement + ' li').removeClass(fadeSlideShowSettings.ListLiActive);
                jQuery('#' + fadeSlideShowSettings.ListElement + ' li').eq(0).addClass(fadeSlideShowSettings.ListLiActive);
                ActSlide = Slides;
                jumpTo(Slides);
                $('.slideshow-overlay').hide();
                return false;
            });
        }

        if (fadeSlideShowSettings.modal)
            $('body').append('<div class="slideshow-overlay"></div>');

        // start autoplay or set it to false
        if (fadeSlideShowSettings.autoplay) {
            autoplay();
        } else {
            intval = false;
        }

        jQuery('#slideshow-wrapper').bind('show', function(e) {
            e.preventDefault();
            $('.slideshow-overlay').show();
            return false;
        });
    });
};